@@ -473,11 +473,14 @@ class BaseCST(ABC):
         decorators_CST: List[cst.Decorator] = []
         for decorator in decorators:
             decorators_CST.append(cst.Decorator(decorator=cst.Name(decorator)))
-        returns: cst.Annotation = cst.Annotation(
-            annotation=cst.Name(return_type),
-            whitespace_before_indicator=cst.SimpleWhitespace(value=' ',),
-            whitespace_after_indicator=cst.SimpleWhitespace(value=' ',)
-        )
+        if return_type:
+            returns: cst.Annotation = cst.Annotation(
+                annotation=cst.Name(return_type),
+                whitespace_before_indicator=cst.SimpleWhitespace(value=' ',),
+                whitespace_after_indicator=cst.SimpleWhitespace(value=' ',)
+            )
+        else:
+            returns = None
         return cst.FunctionDef(
             name=method_name,
             params=cst.Parameters(params=params),
